@@ -12,12 +12,12 @@ use Moose;
 extends 'Ttl::Bin';
 use Ttl::Not;
 use Ttl::And;
-use Reflex::Trait::Observer;
+use Reflex::Trait::Observed;
 
 has and => (
   isa     => 'Ttl::And',
   is      => 'rw',
-  traits  => ['Reflex::Trait::Observer'],
+  traits  => ['Reflex::Trait::Observed'],
   handles => [qw(a b)],
 	setup   => sub { Ttl::And->new() },
 );
@@ -25,7 +25,7 @@ has and => (
 has not => (
   isa     => 'Ttl::Not',
   is      => 'rw',
-  traits  => ['Reflex::Trait::Observer'],
+  traits  => ['Reflex::Trait::Observed'],
 	setup   => sub { Ttl::Not->new() },
 );
 
