@@ -1,36 +1,32 @@
 package Reflex::PID;
 BEGIN {
-  $Reflex::PID::VERSION = '0.071';
+  $Reflex::PID::VERSION = '0.072';
 }
 
 use Moose;
-extends qw(Reflex::Signal);
+extends 'Reflex::Base';
 
-has '+signal' => (
-	required  => 0,
-	default   => 'CHLD',
-);
-
-has 'pid' => (
-	isa       => 'Int',
+has pid => (
 	is        => 'ro',
+	isa       => 'Int',
 	required  => 1,
-	default   => sub { die "required" },
 );
 
-__PACKAGE__->_register_signal_params(qw(pid exit));
+has active => (
+	is      => 'ro',
+	isa     => 'Bool',
+	default => 1,
+);
 
-sub resume {
-	my $self = shift;
-	return unless $self->call_gate("resume");
-	$POE::Kernel::poe_kernel->sig_child($self->pid(), "signal_happened");
-}
-
-sub pause {
-	my $self = shift;
-	return unless $self->call_gate("pause");
-	$POE::Kernel::poe_kernel->sig_child($self->pid(), undef);
-}
+with 'Reflex::Role::PidCatcher' => {
+	pid           => 'pid',
+	active        => 'active',
+	cb_exit       => 'on_exit',
+	method_start  => 'start',
+	method_stop   => 'stop',
+	method_pause  => 'pause',
+	method_resume => 'resume',
+};
 
 1;
 
@@ -42,7 +38,7 @@ Reflex::PID - Observe the exit of a subprocess by its SIGCHLD signal.
 
 =head1 VERSION
 
-version 0.071
+version 0.072
 
 =head1 SYNOPSIS
 
@@ -51,11 +47,11 @@ version 0.071
 
 	use Reflex::PID;
 
-	has sigchild_watcher => (
+	has pid_watcher => (
 		isa    => 'Reflex::PID|Undef',
 		is     => 'rw',
 		traits => ['Reflex::Trait::Observed'],
-		role   => 'sigchld',
+		role   => 'process',
 	);
 
 	sub some_method {
@@ -71,7 +67,7 @@ version 0.071
 		);
 	}
 
-	sub on_sigchld_signal {
+	sub on_process_exit {
 		# Handle the event.
 	}
 
@@ -94,9 +90,9 @@ Reflex::Collection won't know when to destroy them.
 
 =head2 Public Events
 
-=head3 signal
+=head3 exit
 
-Reflex::PID's "signal" event includes two named parameters.  "pid"
+Reflex::PID's "exit" event includes two named parameters.  "pid"
 contains the process ID that exited.  "exit" contains the process'
 exit value---a copy of C<$?> at the time the process exited.  Please
 see L<perlvar/"$?"> for more information about that special Perl
