@@ -1,6 +1,6 @@
 package Reflex::Role::Reactive;
 BEGIN {
-  $Reflex::Role::Reactive::VERSION = '0.071';
+  $Reflex::Role::Reactive::VERSION = '0.072';
 }
 
 use Moose::Role;
@@ -70,7 +70,8 @@ my $singleton_session_id = POE::Session->create(
 		### Signals.
 
 		signal_happened => sub {
-			Reflex::Role::SigCatcher->deliver(@_[ARG0..$#_]);
+			my $signal_class = pop @_;
+			$signal_class->deliver(@_[ARG0..$#_]);
 		},
 
 		### Cross-session emit() is converted into these events.
@@ -196,7 +197,8 @@ has emits_seen => (
 
 # Base class.
 
-sub BUILD {
+sub BUILD {}
+after BUILD => sub {
 	my ($self, $args) = @_;
 
 	# Set up all emitters and watchers.
@@ -267,7 +269,7 @@ sub BUILD {
 
 	# The session has an object.
 	$session_object_count{$self->session_id()}++;
-}
+};
 
 # TODO - Does Moose have sugar for passing named parameters?
 
@@ -588,7 +590,7 @@ Reflex::Role::Reactive - Make an object reactive (aka, event driven).
 
 =head1 VERSION
 
-version 0.071
+version 0.072
 
 =head1 SYNOPSIS
 
