@@ -1,6 +1,6 @@
 package Reflex::Role::SigCatcher;
 BEGIN {
-  $Reflex::Role::SigCatcher::VERSION = '0.071';
+  $Reflex::Role::SigCatcher::VERSION = '0.072';
 }
 use Reflex::Role;
 
@@ -31,7 +31,9 @@ my %signal_param_names;
 
 sub _register_signal_params {
 	my ($class, @names) = @_;
-	$signal_param_names{$class->meta->get_attribute("signal")->default()} = \@names;
+	$signal_param_names{$class->meta->get_attribute("signal")->default()} = (
+		\@names
+	);
 }
 
 sub deliver {
@@ -128,7 +130,9 @@ role {
 		# Be in the session associated with this object.
 		return unless $self->call_gate($method_resume);
 
-		$POE::Kernel::poe_kernel->sig($self->$signal(), "signal_happened");
+		$POE::Kernel::poe_kernel->sig(
+			$self->$signal(), "signal_happened", ref($self)
+		);
 	};
 
 	method $method_stop => sub {
@@ -162,7 +166,7 @@ Reflex::Role::SigCatcher - add signal catching behavior to a class
 
 =head1 VERSION
 
-version 0.071
+version 0.072
 
 =head1 SYNOPSIS
 
@@ -203,7 +207,7 @@ entire implementation of Reflex::SigCatcher, a simple class that
 allows Reflex::Role::SigCatcher to be used as an object.
 
 Reflex::Role::SigCatcher is not suitable for SIGCHLD use.  The
-specialized Reflex::Role::PidReaper class is used for that, and it
+specialized Reflex::Role::PidCatcher class is used for that, and it
 will automatically wait() for processes and return their exit
 statuses.
 
@@ -287,8 +291,8 @@ Reflex::Role::SigCatcher.
 
 L<Reflex>
 L<Reflex::Signal>
-L<Reflex::Role::PidReaper>
-L<Reflex::PidReaper>
+L<Reflex::Role::PidCatcher>
+L<Reflex::PID>
 
 L<Reflex/ACKNOWLEDGEMENTS>
 L<Reflex/ASSISTANCE>
