@@ -1,6 +1,6 @@
 package Reflex::Signal;
 BEGIN {
-  $Reflex::Signal::VERSION = '0.071';
+  $Reflex::Signal::VERSION = '0.072';
 }
 
 use Moose;
@@ -38,7 +38,7 @@ Reflex::Signal - receive callbacks when signals arrive
 
 =head1 VERSION
 
-version 0.071
+version 0.072
 
 =head1 SYNOPSIS
 
@@ -75,8 +75,8 @@ That role's documentation contains important details that won't be
 covered here.
 
 Reflex::Signal is not suitable for SIGCHLD use.  The specialized
-Reflex::PidReaper class is used for that, and it will automatically
-wait() for processes and return their exit statuses.
+Reflex::PID class is used for that, and it will automatically wait()
+for processes and return their exit statuses.
 
 =head2 Public Attributes
 
@@ -195,8 +195,8 @@ Reflex::Stream and a few other classes.
 
 L<Reflex>
 L<Reflex::Role::SigCatcher>
-L<Reflex::Role::PID>
-L<Reflex::PidReaper>
+L<Reflex::Role::PidCatcher>
+L<Reflex::PID>
 
 L<Reflex/ACKNOWLEDGEMENTS>
 L<Reflex/ASSISTANCE>
